@@ -7,8 +7,9 @@ pub enum Error {
     OpenRepo(git2::Error),
     FindGitDir(io::Error),
     Term(io::Error),
+    Termwiz(ratatui::termwiz::Error),
     GitDirUtf8(string::FromUtf8Error),
-    Config(figment::Error),
+    Config(Box<figment::Error>),
     FileWatcher(notify::Error),
     ReadRebaseStatusFile(io::Error),
     ReadBranchName(io::Error),
@@ -24,6 +25,9 @@ pub enum Error {
     GetCurrentBranchUpstream(git2::Error),
     GetCurrentBranchUpstreamUtf8(Utf8Error),
     RemoteNameUtf8(Utf8Error),
+    CannotDeleteCurrentBranch,
+    BranchNameRequired,
+    IsBranchMerged(git2::Error),
     GetRemote(git2::Error),
     ReadGitConfig(git2::Error),
     ReadGitConfigUtf8(Utf8Error),
@@ -63,6 +67,7 @@ impl Display for Error {
             },
             Error::FindGitDir(e) => f.write_fmt(format_args!("Couldn't find git directory: {}", e)),
             Error::Term(e) => f.write_fmt(format_args!("Terminal error: {}", e)),
+            Error::Termwiz(e) => f.write_fmt(format_args!("Terminal error: {}", e)),
             Error::GitDirUtf8(_e) => f.write_str("Git directory not valid UTF-8"),
             Error::Config(e) => f.write_fmt(format_args!("Configuration error: {}", e)),
             Error::FileWatcher(e) => f.write_fmt(format_args!("File watcher error: {}", e)),
@@ -94,6 +99,11 @@ impl Display for Error {
                 f.write_str("Current branch upstream is not valid UTF-8")
             }
             Error::RemoteNameUtf8(_e) => f.write_str("Remote name is not valid UTF-8"),
+            Error::CannotDeleteCurrentBranch => f.write_str("Cannot delete current branch"),
+            Error::BranchNameRequired => f.write_str("Branch name required"),
+            Error::IsBranchMerged(e) => {
+                f.write_fmt(format_args!("Couldn't check if branch is merged: {}", e))
+            }
             Error::GetRemote(e) => f.write_fmt(format_args!("Couldn't get remote: {}", e)),
             Error::ReadGitConfig(e) => f.write_fmt(format_args!("Couldn't read git config: {}", e)),
             Error::ReadGitConfigUtf8(_e) => f.write_str("Git config is not valid UTF-8"),
