@@ -1,11 +1,12 @@
-use crate::Res;
-use git2::{DiffOptions, Repository, StatusOptions};
+use crate::{error::Error, Res};
+use git2::{Repository, StatusOptions};
 
 pub(crate) fn status(repo: &Repository) -> Res<StatusOptions> {
     let mut opts = StatusOptions::new();
 
     opts.include_untracked(
-        repo.config()?
+        repo.config()
+            .map_err(Error::ReadGitConfig)?
             .get_bool("status.showUntrackedFiles")
             .ok()
             .unwrap_or(true),
@@ -13,9 +14,3 @@ pub(crate) fn status(repo: &Repository) -> Res<StatusOptions> {
 
     Ok(opts)
 }
-
-pub(crate) fn diff(_repo: &Repository) -> Res<DiffOptions> {
-    let mut diff_options = DiffOptions::new();
-    diff_options.patience(true);
-    Ok(diff_options)
-}
