@@ -1,8 +1,8 @@
 use super::{Action, OpTrait};
 use crate::{
-    items::TargetData,
+    app::{App, PromptParams, State},
+    item_data::ItemData,
     menu::arg::Arg,
-    state::{PromptParams, State},
     term::Term,
     Res,
 };
@@ -17,14 +17,14 @@ pub(crate) fn init_args() -> Vec<Arg> {
 
 pub(crate) struct FetchAll;
 impl OpTrait for FetchAll {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(|state, term| {
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(|app, term| {
             let mut cmd = Command::new("git");
             cmd.args(["fetch", "--all", "--jobs", "10"]);
-            cmd.args(state.pending_menu.as_ref().unwrap().args());
+            cmd.args(app.state.pending_menu.as_ref().unwrap().args());
 
-            state.close_menu();
-            state.run_cmd_async(term, &[], cmd)?;
+            app.close_menu();
+            app.run_cmd_async(term, &[], cmd)?;
             Ok(())
         }))
     }
@@ -36,9 +36,9 @@ impl OpTrait for FetchAll {
 
 pub(crate) struct FetchElsewhere;
 impl OpTrait for FetchElsewhere {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(move |state: &mut State, term: &mut Term| {
-            let remote = state.prompt(
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(move |app: &mut App, term: &mut Term| {
+            let remote = app.prompt(
                 term,
                 &PromptParams {
                     prompt: "Select remote",
@@ -46,7 +46,7 @@ impl OpTrait for FetchElsewhere {
                 },
             )?;
 
-            push_elsewhere(state, term, &remote)?;
+            push_elsewhere(app, term, &remote)?;
             Ok(())
         }))
     }
@@ -56,13 +56,13 @@ impl OpTrait for FetchElsewhere {
     }
 }
 
-fn push_elsewhere(state: &mut State, term: &mut Term, remote: &str) -> Res<()> {
+fn push_elsewhere(app: &mut App, term: &mut Term, remote: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["fetch"]);
-    cmd.args(state.pending_menu.as_ref().unwrap().args());
+    cmd.args(app.state.pending_menu.as_ref().unwrap().args());
     cmd.arg(remote);
 
-    state.close_menu();
-    state.run_cmd_async(term, &[], cmd)?;
+    app.close_menu();
+    app.run_cmd_async(term, &[], cmd)?;
     Ok(())
 }
