@@ -1,10 +1,10 @@
 use super::{selected_rev, Action, OpTrait};
 use crate::{
+    app::{App, PromptParams, State},
     error::Error,
-    items::TargetData,
+    item_data::ItemData,
     menu::arg::{any_regex, positive_number, Arg},
     screen,
-    state::{PromptParams, State},
     term::Term,
     Res,
 };
@@ -27,9 +27,9 @@ pub(crate) fn init_args() -> Vec<Arg> {
 
 pub(crate) struct LogCurrent;
 impl OpTrait for LogCurrent {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(|state: &mut State, _term: &mut Term| {
-            goto_log_screen(state, None);
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(|app: &mut App, _term: &mut Term| {
+            goto_log_screen(app, None);
             Ok(())
         }))
     }
@@ -41,9 +41,9 @@ impl OpTrait for LogCurrent {
 
 pub(crate) struct LogOther;
 impl OpTrait for LogOther {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(move |state: &mut State, term: &mut Term| {
-            let rev = state.prompt(
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(move |app: &mut App, term: &mut Term| {
+            let rev = app.prompt(
                 term,
                 &PromptParams {
                     prompt: "Log rev",
@@ -52,7 +52,7 @@ impl OpTrait for LogOther {
                 },
             )?;
 
-            log_other(state, term, &rev)?;
+            log_other(app, term, &rev)?;
             Ok(())
         }))
     }
@@ -62,45 +62,47 @@ impl OpTrait for LogOther {
     }
 }
 
-fn log_other(state: &mut State, _term: &mut Term, result: &str) -> Res<()> {
-    let oid_result = match state.repo.revparse_single(result) {
+fn log_other(app: &mut App, _term: &mut Term, result: &str) -> Res<()> {
+    let oid_result = match app.state.repo.revparse_single(result) {
         Ok(rev) => Ok(rev.id()),
         Err(err) => Err(Error::FindGitRev(err)),
     };
 
     if oid_result.is_err() {
-        state.close_menu();
+        app.close_menu();
     }
 
     let oid = oid_result?;
 
-    goto_log_screen(state, Some(oid));
+    goto_log_screen(app, Some(oid));
     Ok(())
 }
 
-fn goto_log_screen(state: &mut State, rev: Option<Oid>) {
-    state.screens.drain(1..);
-    let size = state.screens.last().unwrap().size;
-    let limit = *state
+fn goto_log_screen(app: &mut App, rev: Option<Oid>) {
+    app.state.screens.drain(1..);
+    let size = app.state.screens.last().unwrap().size;
+    let limit = *app
+        .state
         .pending_menu
         .as_ref()
         .and_then(|m| m.args.get("-n"))
         .and_then(|arg| arg.value_as::<u32>())
         .unwrap_or(&u32::MAX);
 
-    let msg_regex_menu = state
+    let msg_regex_menu = app
+        .state
         .pending_menu
         .as_ref()
         .and_then(|m| m.args.get("--grep"));
 
     let msg_regex = msg_regex_menu.and_then(|arg| arg.value_as::<Regex>().cloned());
 
-    state.close_menu();
+    app.close_menu();
 
-    state.screens.push(
+    app.state.screens.push(
         screen::log::create(
-            Rc::clone(&state.config),
-            Rc::clone(&state.repo),
+            Rc::clone(&app.state.config),
+            Rc::clone(&app.state.repo),
             size,
             limit as usize,
             rev,
