@@ -1,8 +1,8 @@
 use super::{selected_rev, Action, OpTrait};
 use crate::{
-    items::TargetData,
+    app::{App, PromptParams, State},
+    item_data::{ItemData, RefKind},
     menu::arg::Arg,
-    state::{PromptParams, State},
     term::Term,
     Res,
 };
@@ -30,13 +30,13 @@ pub(crate) fn init_args() -> Vec<Arg> {
 
 pub(crate) struct RebaseContinue;
 impl OpTrait for RebaseContinue {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(|state: &mut State, term: &mut Term| {
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(|app: &mut App, term: &mut Term| {
             let mut cmd = Command::new("git");
             cmd.args(["rebase", "--continue"]);
 
-            state.close_menu();
-            state.run_cmd_interactive(term, cmd)?;
+            app.close_menu();
+            app.run_cmd_interactive(term, cmd)?;
             Ok(())
         }))
     }
@@ -48,13 +48,13 @@ impl OpTrait for RebaseContinue {
 
 pub(crate) struct RebaseAbort;
 impl OpTrait for RebaseAbort {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(|state: &mut State, term: &mut Term| {
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(|app: &mut App, term: &mut Term| {
             let mut cmd = Command::new("git");
             cmd.args(["rebase", "--abort"]);
 
-            state.close_menu();
-            state.run_cmd(term, &[], cmd)?;
+            app.close_menu();
+            app.run_cmd(term, &[], cmd)?;
             Ok(())
         }))
     }
@@ -66,9 +66,9 @@ impl OpTrait for RebaseAbort {
 
 pub(crate) struct RebaseElsewhere;
 impl OpTrait for RebaseElsewhere {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(move |state: &mut State, term: &mut Term| {
-            let rev = state.prompt(
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(move |app: &mut App, term: &mut Term| {
+            let rev = app.prompt(
                 term,
                 &PromptParams {
                     prompt: "Rebase onto",
@@ -77,7 +77,7 @@ impl OpTrait for RebaseElsewhere {
                 },
             )?;
 
-            rebase_elsewhere(state, term, &rev)?;
+            rebase_elsewhere(app, term, &rev)?;
             Ok(())
         }))
     }
@@ -87,27 +87,35 @@ impl OpTrait for RebaseElsewhere {
     }
 }
 
-fn rebase_elsewhere(state: &mut State, term: &mut Term, rev: &str) -> Res<()> {
+fn rebase_elsewhere(app: &mut App, term: &mut Term, rev: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.arg("rebase");
-    cmd.args(state.pending_menu.as_ref().unwrap().args());
+    cmd.args(app.state.pending_menu.as_ref().unwrap().args());
     cmd.arg(rev);
 
-    state.close_menu();
-    state.run_cmd_interactive(term, cmd)?;
+    app.close_menu();
+    app.run_cmd_interactive(term, cmd)?;
     Ok(())
 }
 
 pub(crate) struct RebaseInteractive;
 impl OpTrait for RebaseInteractive {
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
+    fn get_action(&self, target: &ItemData) -> Option<Action> {
         let action = match target {
-            Some(TargetData::Commit(r) | TargetData::Branch(r)) => {
-                let rev = OsString::from(r);
-                Rc::new(move |state: &mut State, term: &mut Term| {
-                    let args = state.pending_menu.as_ref().unwrap().args();
-                    state.close_menu();
-                    state.run_cmd_interactive(term, rebase_interactive_cmd(&args, &rev))
+            ItemData::Commit { oid, .. }
+            | ItemData::Reference {
+                kind: RefKind::Tag(oid),
+                ..
+            }
+            | ItemData::Reference {
+                kind: RefKind::Branch(oid),
+                ..
+            } => {
+                let rev = OsString::from(oid);
+                Rc::new(move |app: &mut App, term: &mut Term| {
+                    let args = app.state.pending_menu.as_ref().unwrap().args();
+                    app.close_menu();
+                    app.run_cmd_interactive(term, rebase_interactive_cmd(&args, &rev))
                 })
             }
             _ => return None,
@@ -140,14 +148,22 @@ fn parent(reference: &OsStr) -> OsString {
 
 pub(crate) struct RebaseAutosquash;
 impl OpTrait for RebaseAutosquash {
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
+    fn get_action(&self, target: &ItemData) -> Option<Action> {
         let action = match target {
-            Some(TargetData::Commit(r) | TargetData::Branch(r)) => {
-                let rev = OsString::from(r);
-                Rc::new(move |state: &mut State, term: &mut Term| {
-                    let args = state.pending_menu.as_ref().unwrap().args();
-                    state.close_menu();
-                    state.run_cmd_interactive(term, rebase_autosquash_cmd(&args, &rev))
+            ItemData::Commit { oid, .. }
+            | ItemData::Reference {
+                kind: RefKind::Tag(oid),
+                ..
+            }
+            | ItemData::Reference {
+                kind: RefKind::Branch(oid),
+                ..
+            } => {
+                let rev = OsString::from(oid);
+                Rc::new(move |app: &mut App, term: &mut Term| {
+                    let args = app.state.pending_menu.as_ref().unwrap().args();
+                    app.close_menu();
+                    app.run_cmd_interactive(term, rebase_autosquash_cmd(&args, &rev))
                 })
             }
             _ => return None,
