@@ -1,8 +1,8 @@
 use super::{selected_rev, OpTrait};
 use crate::{
-    items::TargetData,
+    app::{App, PromptParams, State},
+    item_data::ItemData,
     menu::arg::Arg,
-    state::{PromptParams, State},
     term::Term,
     Action, Res,
 };
@@ -14,9 +14,9 @@ pub(crate) fn init_args() -> Vec<Arg> {
 
 pub(crate) struct ResetSoft;
 impl OpTrait for ResetSoft {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(move |state: &mut State, term: &mut Term| {
-            let rev = state.prompt(
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(move |app: &mut App, term: &mut Term| {
+            let rev = app.prompt(
                 term,
                 &PromptParams {
                     prompt: "Soft reset to",
@@ -25,7 +25,7 @@ impl OpTrait for ResetSoft {
                 },
             )?;
 
-            reset_soft(state, term, &rev)?;
+            reset_soft(app, term, &rev)?;
             Ok(())
         }))
     }
@@ -35,21 +35,21 @@ impl OpTrait for ResetSoft {
     }
 }
 
-fn reset_soft(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
+fn reset_soft(app: &mut App, term: &mut Term, input: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["reset", "--soft"]);
-    cmd.args(state.pending_menu.as_ref().unwrap().args());
+    cmd.args(app.state.pending_menu.as_ref().unwrap().args());
     cmd.arg(input);
 
-    state.close_menu();
-    state.run_cmd(term, &[], cmd)
+    app.close_menu();
+    app.run_cmd(term, &[], cmd)
 }
 
 pub(crate) struct ResetMixed;
 impl OpTrait for ResetMixed {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(move |state: &mut State, term: &mut Term| {
-            let rev = state.prompt(
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(move |app: &mut App, term: &mut Term| {
+            let rev = app.prompt(
                 term,
                 &PromptParams {
                     prompt: "Mixed reset to",
@@ -58,7 +58,7 @@ impl OpTrait for ResetMixed {
                 },
             )?;
 
-            reset_mixed(state, term, &rev)?;
+            reset_mixed(app, term, &rev)?;
             Ok(())
         }))
     }
@@ -68,21 +68,21 @@ impl OpTrait for ResetMixed {
     }
 }
 
-fn reset_mixed(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
+fn reset_mixed(app: &mut App, term: &mut Term, input: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["reset", "--mixed"]);
-    cmd.args(state.pending_menu.as_ref().unwrap().args());
+    cmd.args(app.state.pending_menu.as_ref().unwrap().args());
     cmd.arg(input);
 
-    state.close_menu();
-    state.run_cmd(term, &[], cmd)
+    app.close_menu();
+    app.run_cmd(term, &[], cmd)
 }
 
 pub(crate) struct ResetHard;
 impl OpTrait for ResetHard {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(move |state: &mut State, term: &mut Term| {
-            let rev = state.prompt(
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(move |app: &mut App, term: &mut Term| {
+            let rev = app.prompt(
                 term,
                 &PromptParams {
                     prompt: "Hard reset to",
@@ -91,7 +91,7 @@ impl OpTrait for ResetHard {
                 },
             )?;
 
-            reset_hard(state, term, &rev)?;
+            reset_hard(app, term, &rev)?;
             Ok(())
         }))
     }
@@ -101,12 +101,12 @@ impl OpTrait for ResetHard {
     }
 }
 
-fn reset_hard(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
+fn reset_hard(app: &mut App, term: &mut Term, input: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.args(["reset", "--hard"]);
-    cmd.args(state.pending_menu.as_ref().unwrap().args());
+    cmd.args(app.state.pending_menu.as_ref().unwrap().args());
     cmd.arg(input);
 
-    state.close_menu();
-    state.run_cmd(term, &[], cmd)
+    app.close_menu();
+    app.run_cmd(term, &[], cmd)
 }
