@@ -1,27 +1,40 @@
 use super::OpTrait;
-use crate::{error::Error, items::TargetData, screen, state::State, Action};
+use crate::{
+    app::State,
+    error::Error,
+    item_data::{ItemData, RefKind},
+    screen, Action,
+};
 use core::str;
 use std::{path::Path, process::Command, rc::Rc};
 
 pub(crate) struct Show;
 impl OpTrait for Show {
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
+    fn get_action(&self, target: &ItemData) -> Option<Action> {
         match target {
-            Some(TargetData::Commit(r) | TargetData::Branch(r)) => goto_show_screen(r.clone()),
-            Some(TargetData::File(u)) => editor(u.as_path(), None),
-            Some(TargetData::Delta { diff, file_i }) => editor(
+            ItemData::Commit { oid, .. }
+            | ItemData::Reference {
+                kind: RefKind::Tag(oid),
+                ..
+            }
+            | ItemData::Reference {
+                kind: RefKind::Branch(oid),
+                ..
+            } => goto_show_screen(oid.clone()),
+            ItemData::File(u) => editor(u.as_path(), None),
+            ItemData::Delta { diff, file_i } => editor(
                 Path::new(&diff.text[diff.file_diffs[*file_i].header.new_file.clone()]),
                 None,
             ),
-            Some(TargetData::Hunk {
+            ItemData::Hunk {
                 diff,
                 file_i,
                 hunk_i,
-            }) => editor(
+            } => editor(
                 Path::new(&diff.text[diff.file_diffs[*file_i].header.new_file.clone()]),
                 Some(diff.file_line_of_first_diff(*file_i, *hunk_i) as u32),
             ),
-            Some(TargetData::Stash { id: _, commit }) => goto_show_screen(commit.clone()),
+            ItemData::Stash { commit, .. } => goto_show_screen(commit.clone()),
             _ => None,
         }
     }
@@ -35,12 +48,12 @@ impl OpTrait for Show {
 }
 
 fn goto_show_screen(r: String) -> Option<Action> {
-    Some(Rc::new(move |state, term| {
-        state.close_menu();
-        state.screens.push(
+    Some(Rc::new(move |app, term| {
+        app.close_menu();
+        app.state.screens.push(
             screen::show::create(
-                Rc::clone(&state.config),
-                Rc::clone(&state.repo),
+                Rc::clone(&app.state.config),
+                Rc::clone(&app.state.repo),
                 term.size().map_err(Error::Term)?,
                 r.clone(),
             )
@@ -54,7 +67,7 @@ pub(crate) const EDITOR_VARS: [&str; 4] = ["GITU_SHOW_EDITOR", "VISUAL", "EDITOR
 fn editor(file: &Path, maybe_line: Option<u32>) -> Option<Action> {
     let file = file.to_str().unwrap().to_string();
 
-    Some(Rc::new(move |state, term| {
+    Some(Rc::new(move |app, term| {
         let configured_editor = EDITOR_VARS
             .into_iter()
             .find_map(|var| std::env::var(var).ok());
@@ -65,10 +78,10 @@ fn editor(file: &Path, maybe_line: Option<u32>) -> Option<Action> {
 
         let cmd = parse_editor_command(&editor, &file, maybe_line);
 
-        state.close_menu();
-        state.run_cmd_interactive(term, cmd)?;
+        app.close_menu();
+        app.run_cmd_interactive(term, cmd)?;
 
-        state.screen_mut().update()
+        app.screen_mut().update()
     }))
 }
 
