@@ -1,8 +1,8 @@
 use super::OpTrait;
 use crate::{
+    app::{App, State},
     git::diff::{Diff, PatchMode},
-    items::TargetData,
-    state::State,
+    item_data::ItemData,
     term::Term,
     Action,
 };
@@ -10,25 +10,27 @@ use std::{ffi::OsString, process::Command, rc::Rc};
 
 pub(crate) struct Stage;
 impl OpTrait for Stage {
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
-        let action = match target.cloned() {
-            Some(TargetData::AllUnstaged) => stage_unstaged(),
-            Some(TargetData::AllUntracked(untracked)) => stage_untracked(untracked),
-            Some(TargetData::File(u)) => stage_file(u.into()),
-            Some(TargetData::Delta { diff, file_i }) => {
-                stage_file(diff.text[diff.file_diffs[file_i].header.new_file.clone()].into())
+    fn get_action(&self, target: &ItemData) -> Option<Action> {
+        let action = match target {
+            ItemData::AllUnstaged(_) => stage_unstaged(),
+            // FIXME can we avoid clone?
+            ItemData::AllUntracked(untracked) => stage_untracked(untracked.clone()),
+            ItemData::File(u) => stage_file(u.into()),
+            ItemData::Delta { diff, file_i } => {
+                stage_file(diff.text[diff.file_diffs[*file_i].header.new_file.clone()].into())
             }
-            Some(TargetData::Hunk {
+            ItemData::Hunk {
                 diff,
                 file_i,
                 hunk_i,
-            }) => stage_patch(diff, file_i, hunk_i),
-            Some(TargetData::HunkLine {
+            } => stage_patch(Rc::clone(diff), *file_i, *hunk_i),
+            ItemData::HunkLine {
                 diff,
                 file_i,
                 hunk_i,
                 line_i,
-            }) => stage_line(diff, file_i, hunk_i, line_i),
+                ..
+            } => stage_line(Rc::clone(diff), *file_i, *hunk_i, *line_i),
             _ => return None,
         };
 
@@ -45,49 +47,53 @@ impl OpTrait for Stage {
 }
 
 fn stage_unstaged() -> Action {
-    Rc::new(move |state: &mut State, term: &mut Term| {
+    Rc::new(move |app: &mut App, term: &mut Term| {
         let mut cmd = Command::new("git");
         cmd.args(["add", "-u", "."]);
 
-        state.close_menu();
-        state.run_cmd(term, &[], cmd)
+        app.close_menu();
+        app.run_cmd(term, &[], cmd)
     })
 }
 
 fn stage_untracked(untracked: Vec<std::path::PathBuf>) -> Action {
-    Rc::new(move |state: &mut State, term: &mut Term| {
+    Rc::new(move |app: &mut App, term: &mut Term| {
         let mut cmd = Command::new("git");
         cmd.arg("add");
         cmd.args(untracked.clone());
 
-        state.close_menu();
-        state.run_cmd(term, &[], cmd)
+        app.close_menu();
+        app.run_cmd(term, &[], cmd)
     })
 }
 
 fn stage_file(file: OsString) -> Action {
-    Rc::new(move |state, term| {
+    Rc::new(move |app, term| {
         let mut cmd = Command::new("git");
         cmd.args(["add"]);
         cmd.arg(&file);
 
-        state.close_menu();
-        state.run_cmd(term, &[], cmd)
+        app.close_menu();
+        app.run_cmd(term, &[], cmd)
     })
 }
 
 fn stage_patch(diff: Rc<Diff>, file_i: usize, hunk_i: usize) -> Action {
-    Rc::new(move |state, term| {
+    Rc::new(move |app, term| {
         let mut cmd = Command::new("git");
         cmd.args(["apply", "--cached"]);
 
-        state.close_menu();
-        state.run_cmd(term, &diff.format_patch(file_i, hunk_i).into_bytes(), cmd)
+        app.close_menu();
+        app.run_cmd(
+            term,
+            &diff.format_hunk_patch(file_i, hunk_i).into_bytes(),
+            cmd,
+        )
     })
 }
 
 fn stage_line(diff: Rc<Diff>, file_i: usize, hunk_i: usize, line_i: usize) -> Action {
-    Rc::new(move |state, term| {
+    Rc::new(move |app, term| {
         let mut cmd = Command::new("git");
         cmd.args(["apply", "--cached", "--recount"]);
 
@@ -95,7 +101,7 @@ fn stage_line(diff: Rc<Diff>, file_i: usize, hunk_i: usize, line_i: usize) -> Ac
             .format_line_patch(file_i, hunk_i, line_i..(line_i + 1), PatchMode::Normal)
             .into_bytes();
 
-        state.close_menu();
-        state.run_cmd(term, &input, cmd)
+        app.close_menu();
+        app.run_cmd(term, &input, cmd)
     })
 }
