@@ -3,14 +3,12 @@ use std::{iter, rc::Rc};
 use crate::{
     config::Config,
     git,
-    items::{self, Item},
+    item_data::{ItemData, SectionHeader},
+    items::{self, hash, Item},
     Res,
 };
 use git2::Repository;
-use ratatui::{
-    layout::Size,
-    text::{Line, Text},
-};
+use ratatui::layout::Size;
 
 use super::Screen;
 
@@ -24,32 +22,26 @@ pub(crate) fn create(
         Rc::clone(&config),
         size,
         Box::new(move || {
-            let style = &config.style;
             let commit = git::show_summary(repo.as_ref(), &reference)?;
             let show = git::show(repo.as_ref(), &reference)?;
-            let details = Text::from(commit.details).lines;
+            let details = commit.details.lines();
 
             Ok(iter::once(Item {
-                id: format!("commit_section_{}", commit.hash).into(),
-                display: Line::styled(format!("commit {}", commit.hash), &style.section_header),
+                id: hash(["commit_section", &commit.hash]),
                 section: true,
                 depth: 0,
+                data: ItemData::Header(SectionHeader::Commit(commit.hash.clone())),
                 ..Default::default()
             })
             .chain(details.into_iter().map(|line| Item {
-                id: format!("commit_{}", commit.hash).into(),
-                display: line,
+                id: hash(["commit", &commit.hash]),
                 depth: 1,
                 unselectable: true,
+                data: ItemData::Raw(line.to_string()),
                 ..Default::default()
             }))
             .chain([items::blank_line()])
-            .chain(items::create_diff_items(
-                Rc::clone(&config),
-                &Rc::new(show),
-                0,
-                false,
-            ))
+            .chain(items::create_diff_items(&Rc::new(show), 0, false))
             .collect())
         }),
     )
