@@ -2,14 +2,14 @@ use super::*;
 
 #[test]
 pub(crate) fn quit() {
-    let state = snapshot!(TestContext::setup_init(), "q");
-    assert!(state.quit);
+    let app = snapshot!(TestContext::setup_init(), "q");
+    assert!(app.state.quit);
 }
 
 #[test]
 pub(crate) fn quit_from_menu() {
-    let state = snapshot!(TestContext::setup_init(), "hq");
-    assert!(!state.quit);
+    let app = snapshot!(TestContext::setup_init(), "hq");
+    assert!(!app.state.quit);
 }
 
 #[test]
@@ -17,8 +17,8 @@ pub(crate) fn confirm_quit_prompt() {
     let mut ctx = TestContext::setup_init();
     ctx.config().general.confirm_quit.enabled = true;
 
-    let state = snapshot!(ctx, "q");
-    assert!(!state.quit);
+    let app = snapshot!(ctx, "q");
+    assert!(!app.state.quit);
 }
 
 #[test]
@@ -26,6 +26,6 @@ pub(crate) fn confirm_quit() {
     let mut ctx = TestContext::setup_init();
     ctx.config().general.confirm_quit.enabled = true;
 
-    let state = snapshot!(ctx, "qy");
-    assert!(state.quit);
+    let app = snapshot!(ctx, "qy");
+    assert!(app.state.quit);
 }
